---
id: 20211122195311
title: Run a demo
tags: [how-to, mkdocs, zettelkasten]
---

# Run a demo

1. Create a new documentation folder
```shell
$ mkdocs new demo
```
2. Create the index file
```shell
$ cd demo
$ cd docs
$ echo "This is the homepage where you can add links to favorite zettels for example" > index.md
```
3. Create a demo zettel file
```shell
$ cat > 20211122110202.md
---
id: 20211122110202
title: Welcome to MkDocs Zettelkasten
tags: [testing, unimportant]
---

# Welcome to MkDocs Zettelkasten

This is a zettel in form of a markdown file.

---
web: [MkDocs Zettelkasten](https://github.com/buvis/mkdocs-zettelkasten)
---

^D
```
The metadata has to be enclosed in `---` lines, and must include `id:`, `title:` and `tags:` properties. Optionally, a footer enclosed in `---` will be rendered in card's footer as a list of references.
4. Edit `mkdocs.yaml`
```yaml
theme:
  name: zettelkasten
plugins:
- tags
- zettelkasten
```
5. Run the server:
```shell
$ mkdocs serve --livereload
```
